@@ -230,7 +230,7 @@ class Experiment:
         except git.InvalidGitRepositoryError:
             if not is_colab() and not is_kaggle():
                 labml_notice(["Not a valid git repository: ",
-                              (lab_singleton().path, Text.value)])
+                              (str(lab_singleton().path), Text.value)])
             self.run.commit = 'unknown'
             self.run.commit_message = ''
             self.run.is_dirty = True
@@ -422,6 +422,9 @@ class Experiment:
 
         if not self.is_evaluate:
             if self.distributed_rank == 0:
+                from labml.internal.computer.configs import computer_singleton
+                computer_singleton().add_project(lab_singleton().path)
+
                 self.run.save_info()
             self._save_pid()
 
