@@ -27,7 +27,7 @@ class Lab:
     path: Optional[Path]
     web_api: Optional[WebAPIConfigs]
 
-    def __init__(self):
+    def __init__(self, path: Optional[Path] = None):
         self.indicators = {}
         self.path = None
         self.check_repo_dirty = None
@@ -39,8 +39,11 @@ class Lab:
         self.__update_configs()
         self.__current_path = None
 
-        python_file = get_caller_file()
-        self.__load_configs(Path(python_file).resolve())
+        if path is None:
+            path = get_caller_file()
+            path = Path(path).resolve()
+
+        self.__load_configs(path)
 
     def set_path(self, path: str):
         self.__load_configs(Path(path).resolve())
@@ -51,6 +54,8 @@ class Lab:
         self.__current_path = path
         config_files = self.__load_config_files(path)
 
+        self.configs = self.__default_config()
+
         if not config_files:
             if not is_colab() and not is_kaggle():
                 labml_notice([(".labml.yaml", Text.value),
@@ -191,20 +196,13 @@ class Lab:
                         config['config_file_path'] = path
                         configs.append(config)
 
-            if str(path) == path.root:
+            if str(path) == path.anchor:
                 break
 
             path = path.parent
 
         return configs
 
-    def get_experiments(self) -> List[Path]:
-        """
-        Get list of experiments
-        """
-        experiments_path = Path(self.experiments)
-        return [child for child in experiments_path.iterdir()]
-
 
 _internal: Optional[Lab] = None
 
