@@ -1,7 +1,6 @@
-from typing import Generic, List, Dict, Optional, TypeVar, TYPE_CHECKING
+from typing import Generic, List, Dict, Optional, TypeVar
 
 from .index_driver import IndexDbDriver
-
 from .model import Key
 
 _KT = TypeVar('_KT')
@@ -19,15 +18,25 @@ class Index(Generic[_KT]):
         db_driver = Index.__db_drivers[cls.__name__]
         db_driver.delete(index_key)
 
-    @classmethod
-    def get(cls, index_key: str) -> Optional[Key[_KT]]:
-        db_driver = Index.__db_drivers[cls.__name__]
-        key = db_driver.get(index_key)
+    @staticmethod
+    def _to_key(key: str):
         if key is None:
             return None
         else:
             return Key(key)
 
+    @classmethod
+    def get(cls, index_key: str) -> Optional[Key[_KT]]:
+        db_driver = Index.__db_drivers[cls.__name__]
+        return Index._to_key(db_driver.get(index_key))
+
+    @classmethod
+    def mget(cls, index_key: List[str]) -> List[Optional[Key[_KT]]]:
+        if not index_key:
+            return []
+        db_driver = Index.__db_drivers[cls.__name__]
+        return [Index._to_key(k) for k in db_driver.mget(index_key)]
+
     @classmethod
     def set(cls, index_key: str, model_key: Key[_KT]):
         db_driver = Index.__db_drivers[cls.__name__]
