@@ -1,4 +1,4 @@
-from typing import Type, TYPE_CHECKING
+from typing import Type, TYPE_CHECKING, List
 
 if TYPE_CHECKING:
     from . import Index
@@ -14,5 +14,8 @@ class IndexDbDriver:
     def get(self, index_key: str) -> str:
         raise NotImplementedError
 
+    def mget(self, index_key: List[str]) -> List[str]:
+        raise NotImplementedError
+
     def set(self, index_key: str, model_key: str):
         raise NotImplementedError
