@@ -1,4 +1,5 @@
 import json
+from typing import Optional
 
 from . import Serializer
 from .utils import encode_keys, decode_keys
@@ -11,5 +12,7 @@ class JsonSerializer(Serializer):
     def to_string(self, data: ModelDict) -> str:
         return json.dumps(encode_keys(data))
 
-    def from_string(self, data: str) -> ModelDict:
+    def from_string(self, data: Optional[str]) -> Optional[ModelDict]:
+        if data is None:
+            return None
         return decode_keys(json.loads(data))
