@@ -1,4 +1,5 @@
 import pickle
+from typing import Optional
 
 from . import Serializer
 from ..types import ModelDict
@@ -11,5 +12,7 @@ class PickleSerializer(Serializer):
     def to_string(self, data: ModelDict) -> bytes:
         return pickle.dumps(data)
 
-    def from_string(self, data: bytes) -> ModelDict:
+    def from_string(self, data: Optional[bytes]) -> Optional[ModelDict]:
+        if data is None:
+            return None
         return pickle.loads(data)
